from lang import lang_select

def get(data, keys, error_info=False, default=None, lang="en"):
    """
    get nested data

    Args:
        data (dict or list): Nested data objects, which can be dictionaries or lists
        keys (list): list of keys or indices to fetch nested data
        default (any, optional): The default value, returned when the acquisition fails, the default is None

    Returns:
        any: Nested data value, if the acquisition fails, return the default value

    Example:
        data = {'foo': {'bar': [1, 2, 3]}}
        value = get(data, ['foo', 'bar', 1])
        print(value)  # Output: 2
    """
    try:
        for key in keys:
            if isinstance(data, dict):
                data = data.get(key, default)
                if data is default:
                    error_msg = lang_select[lang]['KeyError'].format(key=key)
                    raise KeyError(error_msg)
            elif isinstance(data, list):
                if isinstance(key, int):
                    if -len(data) <= key < len(data):
                        data = data[key]
                    else:
                        error_msg = lang_select[lang]['IndexError'].format(key=key)
                        raise IndexError(error_msg)
                else:
                    error_msg = lang_select[lang]['TypeError']
                    raise TypeError(error_msg)
            else:
                error_msg = lang_select[lang]['GeneralError'].format(data_type=type(data).__name__)
                raise TypeError(error_msg)
    except (KeyError, IndexError, TypeError) as e:
        if error_info:
            error_msg = lang_select[lang]['ErrorInfo'].format(str(e))
            print(error_msg)
        else:
            pass
        return default
    return data